# whisper.infimum

A minimalist theme for Whisper, a highly modularized multi-purpose blog engine.

## Installation

WIP

## License

This plugin is released under GNU Affero General Public License (version 3) from the Free Software Foundation, same as the Whisper blog engine as required. A copy of the license should be included with every copy of this plugin, you can also read the license text [here](https://www.gnu.org/licenses/agpl-3.0.html).
